@@ -7,9 +7,15 @@ import time
 import traceback
 
 import yaml
-from meiga import Error, Failure, Result, Success, isFailure, isSuccess
+from meiga import Error, Failure, Result, Success
+from meiga import __version__ as meiga_version
+from meiga import isFailure, isSuccess
 
 from lume import __version__
+
+if meiga_version >= "1.5.0":
+    from meiga import OnFailureHandler
+
 from lume.config import Config
 from lume.config.check_os_list_or_str_item import get_platform
 from lume.config.config_file_not_found_error import ConfigFileNotFoundError
@@ -71,7 +77,11 @@ def get_parser(config):
     )
 
     parser.add_argument(
-        "-v", "--version", action="store_true", help="show lume version number."
+        "-v",
+        "-version",
+        "--version",
+        action="store_true",
+        help="show lume version number.",
     )
     parser.add_argument(
         "-all",
@@ -80,6 +90,9 @@ def get_parser(config):
         dest="all_commands",
         help="run all commands",
     )
+    parser.add_argument(
+        "-check", "--check", type=str, help="check if lume command is available or not"
+    )
     for command in config.get_commands():
         parser.add_argument(
             f"-{command}",
@@ -133,22 +146,39 @@ def check_command_availability(strict_mode, not_known, parser, config_file) -> R
             parser.print_help()
             print(f"\n{not_supported_message}")
             return isFailure
+    return isSuccess
+
+
+def check_given_command(given_command: str, config: Config):
+    if given_command not in config.get_commands():
+        print(f"lume 🔥 => `{given_command}` is not available command ❌ ")
+        return 1
+    else:
+        print(f"lume 🔥 => `{given_command}` is an available command ✅ ")
+        return 0
 
 
 def main():
     start = time.time()
     header = f" 🔥 lume {__version__} ({get_platform()} -- Python {platform.python_version()}) "
     columns = shutil.get_terminal_size().columns
-    print(header.center(columns - 10, "="))
     result = isFailure
     exit_code = 1
     suffix = "(exit code 1)"
     prefix = f"{Colors.FAIL} Failed"
 
     config_file = os.environ.get("LUME_CONFIG_FILENAME", "lume.yml")
-    config = get_config(filename=config_file).unwrap_or_else(
-        on_failure=on_config_failure, failure_args=(Result.__id__, config_file)
-    )
+
+    if meiga_version >= "1.5.0":
+        config = get_config(filename=config_file).unwrap_or_else(
+            on_failure_handler=OnFailureHandler(
+                func=on_config_failure, args=(Result.__id__, config_file)
+            )
+        )
+    else:
+        config = get_config(filename=config_file).unwrap_or_else(
+            on_failure=on_config_failure, failure_args=(Result.__id__, config_file)
+        )
 
     if config:
         parser = get_parser(config)
@@ -166,7 +196,12 @@ def main():
 
             if args.version:
                 print(f"lume 🔥 => {__version__}")
-                return
+                return 0
+
+            if args.check:
+                return check_given_command(args.check, config)
+
+            print(header.center(columns - 10, "="))
 
             selected_actions = [
                 action
@@ -187,9 +222,18 @@ def main():
             selected_actions = [
                 action.replace("command_", "") for action in selected_actions
             ]
-            result = lume_use_case.execute(steps=selected_actions).handle(
-                on_failure=on_execution_failure, failure_args=(Result.__id__)
-            )
+
+            if meiga_version >= "1.5.0":
+                result = lume_use_case.execute(steps=selected_actions).handle(
+                    on_failure_handler=OnFailureHandler(
+                        func=on_execution_failure, args=(Result.__id__,)
+                    )
+                )
+            else:
+                result = lume_use_case.execute(steps=selected_actions).handle(
+                    on_failure=on_execution_failure, failure_args=(Result.__id__,)
+                )
+
             lume_use_case.clear_env()
 
         if result.is_success:
