@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from typing import Optional
 
 from meiga import Error, NotImplementedMethodError, Result
 
@@ -7,5 +8,7 @@ DEFAULT_EXECUTOR_LOG_FILENAME = "lume.executor.log"
 
 class ExecutorService(ABC):
     @abstractmethod
-    def execute(self, command: str, cwd: str, log_filename: str) -> Result[bool, Error]:
+    def execute(
+        self, command: str, cwd: str, log_filename: Optional[str] = None
+    ) -> Result[bool, Error]:
         return NotImplementedMethodError
